@@ -45,7 +45,7 @@ use warnings;
 package AtteanX::Store::LDF;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moo;
 use Attean::API::Store;
@@ -189,14 +189,14 @@ sub get_triples {
 
 Returns an cost estimation for a single LDF triple based on
 estimates. The cost will be in the interval 10-1000 if the supplied
-argument is a L<AtteanX::Store::LDF::Plan::Triple>, undef otherwise.
+argument is a L<AtteanX::Plan::LDF::Triple>, undef otherwise.
 
 =cut
 
 sub cost_for_plan {
 	my $self	= shift;
  	my $plan	= shift;
-	if ($plan->isa('AtteanX::Store::LDF::Plan::Triple')) {
+	if ($plan->isa('AtteanX::Plan::LDF::Triple')) {
 		my $totals = $self->count_triples_estimate();
 		if ($totals < 1) {
 			$self->log->error("Total number of triples in model were $totals, probably an error");
